==> Data-Sah-0.59.tar.gz: Data-Sah-0.59/lib/Data/Sah/Util/Func.pm <==
package Data::Sah::Util::Func;

our $DATE = '2015-05-22'; # DATE
our $VERSION = '0.59'; # VERSION

use 5.010;
use strict;
use warnings;
#use Log::Any '$log';

#use Sub::Install qw(install_sub);

require Exporter;
our @ISA = qw(Exporter);
our @EXPORT_OK = qw(
                       add_func
               );

sub add_func {
    my ($funcset, $func, %opts) = @_;
    # not yet implemented
}

1;
# ABSTRACT: Sah utility routines for adding function

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Util::Func - Sah utility routines for adding function

=head1 VERSION

This document describes version 0.59 of Data::Sah::Util::Func (from Perl distribution Data-Sah), released on 2015-05-22.

=head1 DESCRIPTION

This module provides some utility routines to be used by modules that add Sah
functions.

=head1 FUNCTIONS

=head2 add_func($funcset, $func, %opts)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Data-Sah>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Data-Sah-0.60.tar.gz: Data-Sah-0.60/lib/Data/Sah/Util/Func.pm <==
package Data::Sah::Util::Func;

our $DATE = '2015-05-26'; # DATE
our $VERSION = '0.60'; # VERSION

use 5.010;
use strict;
use warnings;
#use Log::Any '$log';

#use Sub::Install qw(install_sub);

require Exporter;
our @ISA = qw(Exporter);
our @EXPORT_OK = qw(
                       add_func
               );

sub add_func {
    my ($funcset, $func, %opts) = @_;
    # not yet implemented
}

1;
# ABSTRACT: Sah utility routines for adding function

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Util::Func - Sah utility routines for adding function

=head1 VERSION

This document describes version 0.60 of Data::Sah::Util::Func (from Perl distribution Data-Sah), released on 2015-05-26.

=head1 DESCRIPTION

This module provides some utility routines to be used by modules that add Sah
functions.

=head1 FUNCTIONS

=head2 add_func($funcset, $func, %opts)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Data-Sah>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
